update.Kriging: Update a 'Kriging' model object with new points

View source: R/KrigingClass.R

update.KrigingR Documentation

Update a Kriging model object with new points

Description

Update a Kriging model object with new points

Usage

## S3 method for class 'Kriging'
update(object, y_u, ..., X_u = NULL, noise_u = NULL, refit = TRUE)

Arguments

object

S3 Kriging object.

y_u

Numeric vector of new responses (output).

...

Ignored.

X_u

Numeric matrix of new input points.

noise_u

Optional numeric vector of observation noise variances attached to y_u.

refit

Logical. If TRUE the model is refitted (default is TRUE).

Value

No return value. Kriging object argument is modified.

Caution

The method does not return the updated object, but instead changes the content of object. This behaviour is quite unusual in R and differs from the behaviour of update.km in DiceKriging and the update method for class KM.

Author(s)

Yann Richet yann.richet@asnr.fr

Examples

f <- function(x) 1- 1 / 2 * (sin(12 * x) / (1 + x) + 2 * cos(7 * x)*x^5 + 0.7)
plot(f)
set.seed(123)
X <- as.matrix(runif(10))
y <- f(X)
points(X, y, col = "blue")

k <- Kriging(y, X, "matern3_2")

x <- seq(from = 0, to = 1, length.out = 101)
p <- predict(k, x)
lines(x, p$mean, col = "blue")
polygon(c(x, rev(x)), c(p$mean - 2 * p$stdev, rev(p$mean + 2 * p$stdev)),
 border = NA, col = rgb(0, 0, 1, 0.2))

X_u <- as.matrix(runif(3))
y_u <- f(X_u)
points(X_u, y_u, col = "red")

## change the content of the object 'k'
update(k, y_u, X_u)

## include design points to see interpolation
x <- sort(c(X,X_u,seq(from = 0, to = 1, length.out = 101)))
p2 <- predict(k, x)
lines(x, p2$mean, col = "red")
polygon(c(x, rev(x)), c(p2$mean - 2 * p2$stdev, rev(p2$mean + 2 * p2$stdev)),
 border = NA, col = rgb(1, 0, 0, 0.2))

rlibkriging documentation built on May 14, 2026, 1:06 a.m.